@@ -289,6 +289,7 @@ extern int quisk_is_vna;			// is this the VNA program?
 extern int quisk_serial_key_errors;		// Error count for the Quisk internal serial key
 extern double quisk_sidetoneVolume;		// Audio output level of the CW sidetone, 0.0 to 1.0
 extern int quisk_serial_key_down;		// The state of the serial port CW key
+extern int quisk_serial_ptt;			// The state of the serial port PTT
 extern int quisk_hardware_cwkey;		// The state of the hardware CW key from UDP or USB
 extern int quisk_midi_cwkey;			// The state of the MIDI CW key
 extern int quisk_sidetoneFreq;			// Frequency in hertz for the sidetone
@@ -334,7 +335,7 @@ extern PyObject * quisk_freedv_get_rx_char(PyObject *, PyObject *);
 extern PyObject * quisk_freedv_set_options(PyObject *, PyObject *, PyObject *);
 extern PyObject * quisk_set_sparams(PyObject *, PyObject *, PyObject *);
 extern PyObject * quisk_freedv_set_squelch_en(PyObject *, PyObject *);
-extern PyObject * quisk_open_key(PyObject *, PyObject *);
+extern PyObject * quisk_open_key(PyObject *, PyObject *, PyObject *);
 extern PyObject * quisk_close_key(PyObject *, PyObject *);
 extern PyObject * quisk_set_sound_name(PyObject *, PyObject *);
 extern PyObject * quisk_alsa_control_midi(PyObject *, PyObject *, PyObject *);
